function [metric] = obj_to_min_Q7(X,target)
% target values (i.e., the values observed in the data) for second
% moments (column 1), serial correlation (column 2), and correlation with
% GDP (column 3) for the variables y (row 1), c (row 2), i (row 3), h (row
% 4), tb/y (row 5) --> see Table 4.2 in the textbook --> below (around line
% 100) "metric" selects which of these values are actually targeted (and
% minimizes the sum of squared deviations)
%
  
GAMMA = X(1);
HBAR = X(2);
PSSI = X(3);
PHI = X(4);
RHO = X(5);
ETATILDE = X(6);
        
%Calibration -> compute SS values for given parameters
%Time unit is a year
edeir_ss_Q7;

%Evaluate f and its derivates at the steady state by running edeir_model_num_eval.m
edeir_model_num_eval; 
%this is a .m file produced by running edeir_model.m

%First-stage policy functions
[gx,hx,exitflag]=gx_hx(nfy,nfx,nfyp,nfxp); 
%the function gx_hx.m is available online at http://www.columbia.edu/~mu2166/1st_order/1st_order.htm

%Variance/Covariance matrix of innovation to state vector x_t
varshock = nETASHOCK*nETASHOCK';

%standard deviations
[sigy0,sigx0]=mom(gx,hx,varshock);
stds = sqrt(diag(sigy0));

%correlations with output
corr_xy = sigy0(:,noutput)./stds(noutput)./stds;

%serial correlations
[sigy1,sigx1]=mom(gx,hx,varshock,1);
scorr = diag(sigy1)./diag(sigy0);

%make a table containing second moments
num_table = [stds*100  scorr corr_xy];

%From this table, select variables of interest (output, c, ivv, h, tby, cay)
num_table1 = num_table([noutput nc nivv nh ntby  ncay],:);

% target only second moments (except for c), and y's serial correlation, as
% described in Part C of Section 4.2
% metric = sum(abs((num_table1([1 3:end-1],1)-target([1 3:end],1))))+(num_table1(1,2)-target(1,2));

% target second moments sigma_y, sigma_i, sigma_h, sigma_tby, and the
% serial correlations of y, i, and tby
metric = sum(abs((num_table1([1 3:end-1],1)-target([1 3:end],1)).^2))+...
                sum((num_table1([1 3 5],2)-target([1 3 5],2)).^2);

end